[297520] EL for pageContext.request generates wrong class for casting
diff --git a/bundles/org.eclipse.jst.jsp.core/src/org/eclipse/jst/jsp/core/internal/java/jspel/ELGeneratorVisitor.java b/bundles/org.eclipse.jst.jsp.core/src/org/eclipse/jst/jsp/core/internal/java/jspel/ELGeneratorVisitor.java
index acb961c..58b05ed 100644
--- a/bundles/org.eclipse.jst.jsp.core/src/org/eclipse/jst/jsp/core/internal/java/jspel/ELGeneratorVisitor.java
+++ b/bundles/org.eclipse.jst.jsp.core/src/org/eclipse/jst/jsp/core/internal/java/jspel/ELGeneratorVisitor.java
@@ -410,7 +410,7 @@
 				ASTValuePrefix prefix = (ASTValuePrefix) node.jjtGetChild(0);
 				ASTValueSuffix suffix = (ASTValueSuffix) node.jjtGetChild(1);
 				if(prefix.firstToken.image.equals("pageContext") && suffix.getPropertyNameToken().image.equals("request")) {
-					append("((HTTPServletRequest)");
+					append("((HttpServletRequest)");
 				}
 			}
 		}
@@ -460,7 +460,7 @@
 
 			// This is a special case.  Note that the type system, no matter how much type information
 			// we would have wouldn't give us the correct result.  We're looking for "pageContext.request" 
 			// here and will add a downcast to (HTTPServletRequest)
 			
 			append(node.firstToken);
 			append("get" + ucaseName + "()", suffix); //$NON-NLS-1$ //$NON-NLS-2$
@@ -460,7 +460,7 @@
 			// This is a special case.  Note that the type system, no matter how much type information
 			// we would have wouldn't give us the correct result.  We're looking for "pageContext.request" 
-			// here and will add a downcast to (HTTPServletRequest)
+			// here and will add a downcast to (HttpServletRequest)
 			
 			append(node.firstToken);